@@ -5,7 +5,7 @@ with open("README_PyPi.md", "r") as fh:
 
 setuptools.setup(
 	name="rfswarm-reporter",
-	version="1.0.0",
+	version="1.0.1",
 	author="damies13",
 	author_email="damies13+rfswarm@gmail.com",
 	description="rfswarm reporter",
@@ -18,7 +18,7 @@ setuptools.setup(
 	# https://matplotlib.org/stable/users/installing.html
 	# zoneinfo requires python 3.9
 	# tzlocal is needed to get the local timezone in a format that zoneinfo likes
-	install_requires=['configparser', 'pillow', 'pip>=21,>=22', 'matplotlib', 'python-docx', 'openpyxl', 'tzlocal>=4.1'],
+	install_requires=['configparser', 'pillow>=9.1.0', 'pip>=21,>=22', 'matplotlib', 'python-docx', 'openpyxl', 'tzlocal>=4.1'],
 	classifiers=[
 		"Development Status :: 5 - Production/Stable",
 		"Topic :: Software Development :: Testing",
